/*
 *   LADCCA
 *    
 *   Copyright (C) 2002 Robert Ham (node@users.sourceforge.net)
 *    
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <string.h>
#include <arpa/inet.h>
#include <pthread.h>
#include <unistd.h>
                     
#include <ladcca/ladcca.h>

#include "conn.h"

void
conn_init (conn_t * conn)
{
  static unsigned long id = 1;
  conn->id = id;
  id++;
  conn->socket = 0;
  memset (&conn->addr, 0, sizeof (struct sockaddr_in));
  pthread_mutex_init (&conn->lock, NULL);
}

void
conn_free (conn_t * conn)
{
  if (conn->socket)
    close (conn->socket);
  conn->socket = 0;
  memset (&conn->addr, 0, sizeof (struct sockaddr_in));
  pthread_mutex_destroy (&conn->lock);
}

conn_t *
conn_new ()
{
  conn_t * conn;
  conn = cca_malloc (sizeof (conn_t));
  conn_init (conn);
  return conn;
}

void
conn_destroy (conn_t * conn)
{
  conn_free (conn);
  free (conn);
}

void
conn_lock (conn_t * conn)
{
  pthread_mutex_lock (&conn->lock);
}

void
conn_unlock (conn_t * conn)
{
  pthread_mutex_unlock (&conn->lock);
}

/*void
conn_set_id (conn_t * conn, unsigned long id)
{
  conn->id = id;
}*/

void
conn_set_socket (conn_t * conn, int socket)
{
  conn->socket = socket;
}

void
conn_set_addr (conn_t * conn, const struct sockaddr_in * addr)
{
  conn->addr = *addr;
}


unsigned long
conn_get_id (conn_t * conn)
{
  return conn->id;
}

int
conn_get_socket (conn_t * conn)
{
  return conn->socket;
}

const struct sockaddr_in *
conn_get_addr (conn_t * conn)
{
  return &conn->addr;
}

const char *
conn_get_ip (conn_t * conn)
{
  return inet_ntoa(conn->addr.sin_addr);
}

int
conn_get_port (conn_t * conn)
{
  return ntohs (conn->addr.sin_port);
}

const char *
conn_get_str_id (conn_t * conn)
{
  static char id[20];
  
  sprintf (id, "%s:%d", conn_get_ip (conn),
                        conn_get_port (conn));
  
  return id;
}



/* EOF */

