/*
 *   LADCCA
 *    
 *   Copyright (C) 2002 Robert Ham (node@users.sourceforge.net)
 *    
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef __LADCCAD_SERVER_H__
#define __LADCCAD_SERVER_H__

#include <ladcca/ladcca.h>

#include "conn_mgr.h"
#include "client.h"
#include "project.h"
#include "loader.h"

typedef struct _server server_t;

struct _server
{
  conn_mgr_t * conn_mgr;
  loader_t *   loader;
  int          loader_quit;

  cca_list_t * projects;
  char *       default_dir;

  char *       ui_project;
};

void server_init (server_t * server);
void server_free (server_t * server);

server_t * server_new ();
void       server_destroy (server_t * server);
void       server_create_loader  (server_t * server);

const char * server_get_ui_project (server_t * server);
conn_mgr_t * server_get_conn_mgr (server_t * server);
int          server_get_loader_quit (server_t * server);

void server_set_ui_project  (server_t * server, const char * project);
void server_set_conn_mgr    (server_t * server, conn_mgr_t * conn_mgr);
void server_set_loader      (server_t * server, loader_t * loader);
void server_set_default_dir (server_t * server, const char * default_dir);
void server_set_loader_quit (server_t * server, int quit);

void server_main (server_t * server);

project_t * server_find_project_by_name (server_t * server, const char * project_name);
const char * server_create_new_project_name (server_t * server);

#endif /* __LADCCAD_SERVER_H__ */
